You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@fluo.apache.org by mw...@apache.org on 2016/07/14 18:12:16 UTC

[1/2] incubator-fluo git commit: Fixes #705 - Create script to fetch dependencies

Repository: incubator-fluo
Updated Branches:
  refs/heads/master e72a93188 -> 2f32661da


Fixes #705 - Create script to fetch dependencies


Project: http://git-wip-us.apache.org/repos/asf/incubator-fluo/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-fluo/commit/9e82f48f
Tree: http://git-wip-us.apache.org/repos/asf/incubator-fluo/tree/9e82f48f
Diff: http://git-wip-us.apache.org/repos/asf/incubator-fluo/diff/9e82f48f

Branch: refs/heads/master
Commit: 9e82f48fa3e0172742bb7d9b78344f5f18e99b42
Parents: e72a931
Author: Mike Walch <mw...@gmail.com>
Authored: Thu Jul 14 10:57:32 2016 -0400
Committer: Mike Walch <mw...@gmail.com>
Committed: Thu Jul 14 10:57:32 2016 -0400

----------------------------------------------------------------------
 docs/prod-fluo-setup.md                         |  49 ++++----
 modules/distribution/pom.xml                    |   9 --
 modules/distribution/src/main/assembly/bin.xml  |  72 +++---------
 .../distribution/src/main/config/fluo-env.sh    |  10 +-
 modules/distribution/src/main/deps/README.md    |  14 ---
 modules/distribution/src/main/deps/pom.xml      |  64 -----------
 modules/distribution/src/main/lib/ahz/pom.xml   |  77 +++++++++++++
 modules/distribution/src/main/lib/fetch.sh      | 113 +++++++++++++++++++
 8 files changed, 239 insertions(+), 169 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/docs/prod-fluo-setup.md
----------------------------------------------------------------------
diff --git a/docs/prod-fluo-setup.md b/docs/prod-fluo-setup.md
index dd633a0..e2015ca 100644
--- a/docs/prod-fluo-setup.md
+++ b/docs/prod-fluo-setup.md
@@ -31,35 +31,44 @@ in `modules/distribution/target`:
 Install Fluo
 ------------
 
-When you have a distribution tarball built for your environment, follow these steps
-to install Fluo.
+After you obtain a Fluo distribution tarball, follow these steps to install Fluo.
 
-First, choose a directory with plenty of space and untar the distribution:
+1. Choose a directory with plenty of space and untar the distribution:
 
-    tar -xvzf fluo-1.0.0-beta-2-bin.tar.gz
+        tar -xvzf fluo-1.0.0-beta-2-bin.tar.gz
 
-Verify that your distribution has the same versions of Hadoop & Accumulo as your environment:
-
-    cd fluo-1.0.0-beta-2
-    ls lib/hadoop-* lib/accumulo-*
-
-Next, copy the example configuration to the base of your configuration directory to create
+2. Copy the example configuration to the base of your configuration directory to create
 the default configuration for your Fluo install:
 
-    cp conf/examples/* conf/
+        cp conf/examples/* conf/
 
-The default configuration will be used as the base configuration for each new application.
-Therefore, you should modify [fluo.properties] for your environment.  However, you should not
-configure any application settings (like observers). 
+    The default configuration will be used as the base configuration for each new application.
 
-NOTE - All properties that have a default are set with it.  Uncomment a property if you want 
+3. Modify [fluo.properties] for your environment.  However, you should not configure any 
+application settings (like observers). 
+
+    NOTE - All properties that have a default are set with it.  Uncomment a property if you want 
 to use a value different than the default.  Properties that are unset and uncommented must be
 set by the user.
 
-To run, Fluo requires the Hadoop, Accumulo, and Zookeeper jars for the versions
-running on the cluster where Fluo will run.  In order to configure this a
-classpath must be constructed with these jars for Fluo.  This can be done by
-editing `conf/fluo-env.sh`, which also contains further documentation.  
+4. Fluo needs build its classpath using jars from the version of Hadoop, Accumulo, and Zookeeper
+that you are using. Choose one of the two ways below to make these jars available to Fluo:
+
+    * Set `HADOOP_PREFIX`, `ACCUMULO_HOME`, and `ZOOKEEPER_HOME` in your environment or configure
+    these variables in [fluo-env.sh].  Fluo will look in these locations for jars.
+    * Run `./lib/fetch.sh ahz` to download Hadoop, Accumulo, and Zookeeper jars to `lib/ahz` and
+    configure [fluo-env.sh] to look in this directory. By default, this command will download the
+    default versions set in [lib/ahz/pom.xml]. If you are not using the default versions, you can
+    override them:
+    
+            ./lib/fetch.sh ahz -Daccumulo.version=1.7.1 -Dhadoop.version=2.6.3 -Dzookeeper.version=3.4.8
+
+5. Fluo needs more dependencies than what is available from Hadoop, Accumulo, and Zookeeper.
+These extra dependencies need to be downloaded to `lib/` using the command below:
+
+        ./lib/fetch.sh extra
+
+You are now ready to use the Fluo command script.
 
 Fluo command script
 -------------------
@@ -210,3 +219,5 @@ distribution on every node in your cluster.
 [release]: https://github.com/apache/incubator-fluo/releases
 [phrasecount]: https://github.com/fluo-io/phrasecount
 [fluo.properties]: ../modules/distribution/src/main/config/fluo.properties
+[fluo-env.sh]: ../modules/distribution/src/main/config/fluo-env.sh
+[lib/ahz/pom.xml]: ../modules/distribution/src/main/lib/ahz/pom.xml

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/pom.xml
----------------------------------------------------------------------
diff --git a/modules/distribution/pom.xml b/modules/distribution/pom.xml
index bc2aacf..f159650 100644
--- a/modules/distribution/pom.xml
+++ b/modules/distribution/pom.xml
@@ -81,15 +81,6 @@
           </execution>
         </executions>
       </plugin>
-      <plugin>
-        <groupId>org.apache.rat</groupId>
-        <artifactId>apache-rat-plugin</artifactId>
-        <configuration>
-          <excludes>
-            <exclude>src/main/deps/**</exclude>
-          </excludes>
-        </configuration>
-      </plugin>
     </plugins>
   </build>
   <profiles>

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/assembly/bin.xml
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/assembly/bin.xml b/modules/distribution/src/main/assembly/bin.xml
index da9d0e0..aca8c63 100644
--- a/modules/distribution/src/main/assembly/bin.xml
+++ b/modules/distribution/src/main/assembly/bin.xml
@@ -26,8 +26,7 @@
       <useProjectArtifact>true</useProjectArtifact>
       <scope>runtime</scope>
       <outputFileNameMapping>${artifact.artifactId}${dashClassifier?}-${artifact.version}.${artifact.extension}</outputFileNameMapping>
-      <useTransitiveDependencies>true</useTransitiveDependencies>
-      <useTransitiveFiltering>true</useTransitiveFiltering>
+      <useTransitiveDependencies>false</useTransitiveDependencies>
       <includes>
         <include>org.apache.fluo:fluo-api</include>
         <include>org.apache.fluo:fluo-accumulo</include>
@@ -35,57 +34,6 @@
         <include>org.apache.fluo:fluo-mini</include>
         <include>org.apache.fluo:fluo-mapreduce</include>
         <include>org.apache.fluo:fluo-cluster</include>
-        <include>org.slf4j:slf4j-api</include>
-        <include>org.apache.curator:curator-framework</include>
-        <include>org.apache.curator:curator-recipes</include>
-      </includes>
-      <excludes>
-        <exclude>org.apache.accumulo:*</exclude>
-        <exclude>org.apache.thrift:*</exclude>
-        <exclude>org.apache.hadoop:*</exclude>
-        <exclude>org.apache.zookeeper:zookeeper</exclude>
-        <exclude>*:slf4j-log4j12</exclude>
-        <exclude>*:log4j</exclude>
-        <exclude>*:logback-classic</exclude>
-        <exclude>*:logback-core</exclude>
-        <exclude>*:log4j-over-slf4j</exclude>
-      </excludes>
-    </dependencySet>
-    <dependencySet>
-        <!-- this is in separate section because it was transitively filtered -->
-        <outputDirectory>lib</outputDirectory>
-        <directoryMode>0755</directoryMode>
-        <fileMode>0644</fileMode>
-        <!-- was having a problem with version 2.2.2 from Accumulo-->
-        <includes>
-          <include>com.google.code.gson:gson</include>
-        </includes>
-    </dependencySet>
-    <dependencySet>
-      <outputDirectory>lib/log4j</outputDirectory>
-      <directoryMode>0755</directoryMode>
-      <fileMode>0644</fileMode>
-      <useProjectArtifact>true</useProjectArtifact>
-      <scope>runtime</scope>
-      <outputFileNameMapping>${artifact.artifactId}${dashClassifier?}-${artifact.version}.${artifact.extension}</outputFileNameMapping>
-      <useTransitiveDependencies>true</useTransitiveDependencies>
-      <includes>
-        <include>*:slf4j-log4j12</include>
-        <include>*:log4j</include>
-      </includes>
-    </dependencySet>
-    <dependencySet>
-      <outputDirectory>lib/logback</outputDirectory>
-      <directoryMode>0755</directoryMode>
-      <fileMode>0644</fileMode>
-      <useProjectArtifact>true</useProjectArtifact>
-      <scope>runtime</scope>
-      <outputFileNameMapping>${artifact.artifactId}${dashClassifier?}-${artifact.version}.${artifact.extension}</outputFileNameMapping>
-      <useTransitiveDependencies>true</useTransitiveDependencies>
-      <includes>
-        <include>*:logback-classic</include>
-        <include>*:logback-core</include>
-        <include>*:log4j-over-slf4j</include>
       </includes>
     </dependencySet>
   </dependencySets>
@@ -95,9 +43,9 @@
       <directory>${project.basedir}/../../</directory>
       <outputDirectory>/</outputDirectory>
       <includes>
+        <include>DISCLAIMER</include>
         <include>LICENSE</include>
-        <include>AUTHORS</include>
-        <include>CHANGES</include>
+        <include>NOTICE</include>
         <include>README.md</include>
       </includes>
     </fileSet>
@@ -117,10 +65,18 @@
       </includes>
     </fileSet>
     <fileSet>
-      <directory>src/main/deps</directory>
-      <outputDirectory>lib/deps</outputDirectory>
+      <directory>src/main/lib</directory>
+      <outputDirectory>lib</outputDirectory>
+      <fileMode>755</fileMode>
       <includes>
-        <include>*</include>
+        <include>fetch.sh</include>
+      </includes>
+    </fileSet>
+    <fileSet>
+      <directory>src/main/lib/ahz</directory>
+      <outputDirectory>lib/ahz</outputDirectory>
+      <includes>
+        <include>pom.xml</include>
       </includes>
     </fileSet>
     <fileSet>

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/config/fluo-env.sh
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/deps/README.md b/modules/distribution/src/main/deps/README.md
deleted file mode 100644
index 0457fe8..0000000
--- a/modules/distribution/src/main/deps/README.md
+++ /dev/null
@@ -1,14 +0,0 @@
-Fluo Dependencies
------------------
-
-This directory provides a simple maven pom that can be used to fetch Accumulo,
-Hadoop, and Zookeeper depedencies.   You should fetch the versions of these
-dependencies that are installed on your system.
-
-    cd $FLUO_HOME/lib/deps/
-    #edit pom to reflect versions of Software on your system
-    vim pom.xml
-    rm *.jar;mvn package clean
-
-After doing this edit `$FLUO_HOME/conf/fluo-env.sh` to add
-`$FLUO_HOME/lib/deps/*` to the classpath.

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/deps/pom.xml
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/deps/pom.xml b/modules/distribution/src/main/deps/pom.xml
deleted file mode 100644
index 68c2576..0000000
--- a/modules/distribution/src/main/deps/pom.xml
+++ /dev/null
@@ -1,64 +0,0 @@
-<project>
-  
-  <modelVersion>4.0.0</modelVersion>
-  <packaging>jar</packaging>
-  <groupId>a</groupId>
-  <artifactId>a</artifactId>
-  <version>a</version>
-
-  <properties>
-    <accumulo.version>1.7.1</accumulo.version>
-    <hadoop.version>2.6.3</hadoop.version>
-    <zookeeper.version>3.4.8</zookeeper.version>
-  </properties>
-
-  <dependencies>
-    <dependency>
-      <groupId>org.apache.accumulo</groupId>
-      <artifactId>accumulo-core</artifactId>
-      <version>${accumulo.version}</version>
-    </dependency>
-    <dependency>
-      <groupId>org.apache.hadoop</groupId>
-      <artifactId>hadoop-client</artifactId>
-      <version>${hadoop.version}</version>
-    </dependency>
-    <dependency>
-      <groupId>org.apache.hadoop</groupId>
-      <artifactId>hadoop-yarn-client</artifactId>
-      <version>${hadoop.version}</version>
-    </dependency>
-    <dependency>
-      <groupId>org.apache.zookeeper</groupId>
-      <artifactId>zookeeper</artifactId>
-      <version>${zookeeper.version}</version>
-    </dependency>
-  </dependencies>
-
-  <build>
-    <plugins>
-      <plugin>
-        <groupId>org.apache.maven.plugins</groupId>
-        <artifactId>maven-dependency-plugin</artifactId>
-        <version>2.10</version>
-        <executions>
-          <execution>
-            <id>copy-dependencies</id>
-            <phase>package</phase>
-            <goals>
-              <goal>copy-dependencies</goal>
-            </goals>
-            <configuration>
-              <outputDirectory>${project.build.directory}/..</outputDirectory>
-              <overWriteReleases>false</overWriteReleases>
-              <overWriteSnapshots>false</overWriteSnapshots>
-              <overWriteIfNewer>true</overWriteIfNewer>
-              <excludeArtifactIds>guava,gson,asm,log4j,slf4j-api,slf4j-log4j12</excludeArtifactIds>
-              <includeScope>runtime</includeScope>
-            </configuration>
-          </execution>
-        </executions>
-      </plugin>
-    </plugins>
-  </build>
-</project>

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/lib/ahz/pom.xml
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/lib/ahz/pom.xml b/modules/distribution/src/main/lib/ahz/pom.xml
new file mode 100644
index 0000000..d08c597
--- /dev/null
+++ b/modules/distribution/src/main/lib/ahz/pom.xml
@@ -0,0 +1,77 @@
+<project>
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one or more contributor license
+  agreements. See the NOTICE file distributed with this work for additional information regarding
+  copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
+  "License"); you may not use this file except in compliance with the License. You may obtain a
+  copy of the License at
+
+     http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software distributed under the License
+  is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+  or implied. See the License for the specific language governing permissions and limitations under
+  the License.
+-->
+  <modelVersion>4.0.0</modelVersion>
+  <packaging>jar</packaging>
+  <groupId>a</groupId>
+  <artifactId>a</artifactId>
+  <version>a</version>
+
+  <properties>
+    <accumulo.version>1.7.1</accumulo.version>
+    <hadoop.version>2.6.3</hadoop.version>
+    <zookeeper.version>3.4.8</zookeeper.version>
+  </properties>
+
+  <dependencies>
+    <dependency>
+      <groupId>org.apache.accumulo</groupId>
+      <artifactId>accumulo-core</artifactId>
+      <version>${accumulo.version}</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.hadoop</groupId>
+      <artifactId>hadoop-client</artifactId>
+      <version>${hadoop.version}</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.hadoop</groupId>
+      <artifactId>hadoop-yarn-client</artifactId>
+      <version>${hadoop.version}</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.zookeeper</groupId>
+      <artifactId>zookeeper</artifactId>
+      <version>${zookeeper.version}</version>
+    </dependency>
+  </dependencies>
+
+  <build>
+    <plugins>
+      <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
+        <artifactId>maven-dependency-plugin</artifactId>
+        <version>2.10</version>
+        <executions>
+          <execution>
+            <id>copy-dependencies</id>
+            <phase>package</phase>
+            <goals>
+              <goal>copy-dependencies</goal>
+            </goals>
+            <configuration>
+              <outputDirectory>${project.build.directory}/..</outputDirectory>
+              <overWriteReleases>false</overWriteReleases>
+              <overWriteSnapshots>false</overWriteSnapshots>
+              <overWriteIfNewer>true</overWriteIfNewer>
+              <excludeArtifactIds>guava,gson,asm,log4j,slf4j-api,slf4j-log4j12</excludeArtifactIds>
+              <includeScope>runtime</includeScope>
+            </configuration>
+          </execution>
+        </executions>
+      </plugin>
+    </plugins>
+  </build>
+</project>

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/lib/fetch.sh
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/lib/fetch.sh b/modules/distribution/src/main/lib/fetch.sh
new file mode 100755
index 0000000..37fbff2
--- /dev/null
+++ b/modules/distribution/src/main/lib/fetch.sh
@@ -0,0 +1,113 @@
+#! /usr/bin/env bash
+
+# Licensed to the Apache Software Foundation (ASF) under one or more contributor license
+# agreements. See the NOTICE file distributed with this work for additional information regarding
+# copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance with the License. You may obtain a
+# copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software distributed under the License
+# is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+# or implied. See the License for the specific language governing permissions and limitations under
+# the License.
+
+lib_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
+maven_prefix=https://repo1.maven.org/maven2
+
+function download {
+  IFS=':' read -ra DEP <<< "$1" 
+  dir=$lib_dir/
+  if [ -n "$2" ]; then
+    dir=$lib_dir/$2
+    if [ ! -d $dir ]; then
+      mkdir $dir
+    fi
+  fi
+  group=${DEP[0]}
+  artifact=${DEP[1]}
+  ftype=${DEP[2]}
+  version=${DEP[3]}
+  fn=$artifact-$version.$ftype
+  path="${group//.//}/$artifact/$version/$fn"
+  download_url=$maven_prefix/$path
+
+  if [ -f $dir/$fn ]; then
+    echo "SUCCESS: Dependency exists - $dir/$fn"
+  else 
+    wget -q $download_url -P $dir
+    if [ $? == 0 ]; then
+      echo "SUCCESS: Dependency downloaded from $download_url"
+    else
+      echo "ERROR: Dependency download failed - $download_url"
+    fi
+  fi
+}
+
+case "$1" in
+ahz)
+  echo "Fetching Hadoop, Accumulo, & Zookeeper dependencies"
+  cd $lib_dir/ahz
+  rm -f *.jar
+  mvn clean package ${*:2}
+  ;;
+extra)
+  echo "Fetching extra Fluo dependencies"
+  download aopalliance:aopalliance:jar:1.0
+  download ch.qos.logback:logback-classic:jar:1.1.3 ./logback
+  download ch.qos.logback:logback-core:jar:1.1.3 ./logback
+  download com.101tec:zkclient:jar:0.3
+  download com.beust:jcommander:jar:1.32
+  download com.google.code.findbugs:jsr305:jar:2.0.1
+  download com.google.code.gson:gson:jar:2.2.4
+  download com.google.guava:guava:jar:13.0.1
+  download com.google.inject:guice:jar:4.0
+  download com.yammer.metrics:metrics-annotation:jar:2.2.0
+  download com.yammer.metrics:metrics-core:jar:2.2.0
+  download commons-collections:commons-collections:jar:3.2.1
+  download commons-configuration:commons-configuration:jar:1.10
+  download commons-io:commons-io:jar:2.4
+  download io.dropwizard.metrics:metrics-core:jar:3.1.1
+  download io.dropwizard.metrics:metrics-graphite:jar:3.1.1
+  download javax.inject:javax.inject:jar:1
+  download log4j:log4j:jar:1.2.17 ./log4j
+  download net.sf.jopt-simple:jopt-simple:jar:3.2
+  download org.apache.curator:curator-client:jar:2.7.1
+  download org.apache.curator:curator-framework:jar:2.7.1
+  download org.apache.curator:curator-recipes:jar:2.7.1
+  download org.apache.kafka:kafka_2.10:jar:0.8.0
+  download org.apache.twill:twill-api:jar:0.6.0-incubating
+  download org.apache.twill:twill-common:jar:0.6.0-incubating
+  download org.apache.twill:twill-core:jar:0.6.0-incubating
+  download org.apache.twill:twill-discovery-api:jar:0.6.0-incubating
+  download org.apache.twill:twill-discovery-core:jar:0.6.0-incubating
+  download org.apache.twill:twill-yarn:jar:0.6.0-incubating
+  download org.apache.twill:twill-zookeeper:jar:0.6.0-incubating
+  download org.hdrhistogram:HdrHistogram:jar:2.1.8
+  download org.mpierce.metrics.reservoir:hdrhistogram-metrics-reservoir:jar:1.1.0
+  download org.ow2.asm:asm-all:jar:5.0.2
+  download org.scala-lang:scala-compiler:jar:2.10.1
+  download org.scala-lang:scala-library:jar:2.10.1
+  download org.scala-lang:scala-reflect:jar:2.10.1
+  download org.slf4j:jcl-over-slf4j:jar:1.7.2
+  download org.slf4j:log4j-over-slf4j:jar:1.7.12 ./logback
+  download org.slf4j:slf4j-api:jar:1.7.12
+  download org.slf4j:slf4j-log4j12:jar:1.7.12 ./log4j
+  download org.xerial.snappy:snappy-java:jar:1.0.5
+  echo -e "Done!\n"
+  echo "NOTE - The dependencies downloaded have been tested with some versions of Hadoop, Zookeeper, and Accumulo."
+  echo "There is no guarantee they will work with all versions. Fluo chose to defer dependency resolution to as"
+  echo "late as possible in order to make it easier to resolve dependency conflicts.  If you run into a dependency"
+  echo "conflict in your environment, please consider bringing it up on the Fluo dev list."
+  ;;
+*)
+  echo -e "Usage: fetch.sh <DEPENDENCIES>\n"
+  echo -e "where <DEPENDENCIES> can be the following:\n"
+  echo "   ahz       Download Accumulo, Hadoop, Zookeeper dependencies"
+  echo -e "   extra     Download extra Fluo dependencies\n"
+  echo "For 'ahz', the versions of Hadoop, Accumulo, & Zookeeper are specifed in ahz/pom.xml."
+  echo -e "However, you can override them using the command below:\n"
+  echo "./fetch.sh ahz -Daccumulo.version=1.7.1 -Dhadoop.version=2.6.3 -Dzookeeper.version=3.4.8"
+esac
+


[2/2] incubator-fluo git commit: Merge branch 'fluo-705'

Posted by mw...@apache.org.
Merge branch 'fluo-705'


Project: http://git-wip-us.apache.org/repos/asf/incubator-fluo/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-fluo/commit/2f32661d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-fluo/tree/2f32661d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-fluo/diff/2f32661d

Branch: refs/heads/master
Commit: 2f32661daa789c41ae89cea61e76c56e1a70b4a1
Parents: b2c91b9 9e82f48
Author: Mike Walch <mw...@gmail.com>
Authored: Thu Jul 14 13:58:04 2016 -0400
Committer: Mike Walch <mw...@gmail.com>
Committed: Thu Jul 14 13:58:04 2016 -0400

----------------------------------------------------------------------
 docs/applications.md                            |  16 +--
 docs/grafana.md                                 |  14 +--
 docs/metrics.md                                 |   6 +-
 docs/prod-fluo-setup.md                         |  49 +++++---
 .../org/apache/fluo/api/client/FluoAdmin.java   |   8 +-
 .../org/apache/fluo/api/client/FluoFactory.java |  30 +++--
 .../fluo/api/config/FluoConfiguration.java      |   6 +-
 .../fluo/api/config/SimpleConfiguration.java    |   2 +
 .../apache/fluo/core/client/FluoAdminImpl.java  |   5 +-
 .../apache/fluo/core/metrics/MetricNames.java   |   8 +-
 modules/distribution/pom.xml                    |   9 --
 modules/distribution/src/main/assembly/bin.xml  |  72 +++---------
 .../distribution/src/main/config/fluo-env.sh    |  10 +-
 .../src/main/config/fluo.properties             | 116 +++++++++----------
 modules/distribution/src/main/config/log4j.xml  |   2 +-
 .../distribution/src/main/config/logback.xml    |   4 +-
 modules/distribution/src/main/deps/README.md    |  14 ---
 modules/distribution/src/main/deps/pom.xml      |  64 ----------
 modules/distribution/src/main/lib/ahz/pom.xml   |  77 ++++++++++++
 modules/distribution/src/main/lib/fetch.sh      | 113 ++++++++++++++++++
 modules/distribution/src/main/scripts/fluo      |   2 +-
 .../org/apache/fluo/integration/log/LogIT.java  |  10 +-
 22 files changed, 353 insertions(+), 284 deletions(-)
----------------------------------------------------------------------
diff --git a/modules/distribution/src/main/config/fluo-env.sh b/modules/distribution/src/main/config/fluo-env.sh
index b344775..118b85c 100755
--- a/modules/distribution/src/main/config/fluo-env.sh
+++ b/modules/distribution/src/main/config/fluo-env.sh
@@ -15,7 +15,6 @@
 # export statement to use the correct directory.  Remove the test
 # statement to override any previously set environment.
 
-
 test -z "$HADOOP_PREFIX" && export HADOOP_PREFIX=/path/to/hadoop
 
 # The classpath for Fluo must be defined.  The Fluo tarball does not include
@@ -66,14 +65,15 @@ setupClasspathFromSystem()
 
 
 # This function obtains Accumulo, Hadoop, and Zookeeper jars from
 # $FLUO_HOME/lib/deps/. Before using this function, go to that directoy and
 # follow the readme to download the dependencies.
 setupClasspathFromLib(){
-  CLASSPATH="$FLUO_HOME/lib/*:$FLUO_HOME/lib/logback/*:$FLUO_HOME/lib/deps/*"
+  CLASSPATH="$FLUO_HOME/lib/*:$FLUO_HOME/lib/logback/*:$FLUO_HOME/lib/ahz/*"
 }
 
 # Call one of the following functions to setup the classpath or write your own
-# bash code to setup the classpath for Fluo.
+# bash code to setup the classpath for Fluo. You must also run the command
+# `./lib/fetch.sh extra` to download extra Fluo dependencies before using Fluo.
 
 setupClasspathFromSystem
 #setupClasspathFromLib

http://git-wip-us.apache.org/repos/asf/incubator-fluo/blob/9e82f48f/modules/distribution/src/main/deps/README.md
----------------------------------------------------------------------
@@ -66,14 +65,15 @@ setupClasspathFromSystem()
 
 # This function obtains Accumulo, Hadoop, and Zookeeper jars from
-# $FLUO_HOME/lib/deps/. Before using this function, go to that directoy and
-# follow the readme to download the dependencies.
+# $FLUO_HOME/lib/ahz/. Before using this function, make sure you run
+# `./lib/fetch.sh ahz` to download dependencies to this directory.
 setupClasspathFromLib(){